<?php
	require_once '../connection/DataBase.class.php';

	class AcademicsDAO extends DataBase{
		private $pdo;
		private $conn;
		private $sql;
		private $query;
		private $rows;
		
		/*Salvar um novo acadêmico*/
		public function salveAcademic($data){
			setlocale(LC_ALL, "pt_BR", "pt_BR.iso-8859-1", "pt_BR.utf-8", "portuguese");
			date_default_timezone_set('America/Campo_Grande');
				
			/*Selecionando dados de conexao com o BD*/
			$this->conn = new DataBase();
				
			$this->pdo = $this->conn->DatabaseDefault();
			
			$this->sql = "INSERT INTO academic (`name`, `rgm`, `password`, `date_insert`) VALUES (?, ?, ?, ?)";
			
			$this->query = $this->pdo->prepare($this->sql);
			
			$this->query->bindValue(1, $data['name']);
			$this->query->bindValue(2, $data['rgm']);
			$this->query->bindValue(3, $this->generatePassword($data['rgm']));
			$this->query->bindValue(4, date("Y/m/d H:i:s"));
			
			if($this->query->execute()){
				$lastId = $this->pdo->lastInsertId();
				
				$this->sql = "INSERT INTO academic_contact (`email`, `cod_academic`) VALUES (?, ?)";
				
				$this->query2 = $this->pdo->prepare($this->sql);
				
				$this->query2->bindValue(1, $data['email']);
				$this->query2->bindValue(2, $lastId);
				
				if($this->query2->execute()){
					parent::__destruct();
						
					return array("success" => 1);
				}else{
					$this->queryError = $this->query2->errorInfo();
						
					parent::__destruct();
						
					return array("success" => 0, "alert" => "Error - ".$this->queryError[2]);
				}
			}else{
				$this->queryError = $this->query->errorInfo();
					
				parent::__destruct();
					
				return array("success" => 0, "alert" => "Error - ".$this->queryError[2]);
			}
		}
		/*Salvar os acadêmicos de acordo com a matéria*/
		public function salveAcademicAndMatter($data){
			setlocale(LC_ALL, "pt_BR", "pt_BR.iso-8859-1", "pt_BR.utf-8", "portuguese");
			date_default_timezone_set('America/Campo_Grande');
			
			/*Selecionando dados de conexao com o BD*/
			$this->conn = new DataBase();
			
			$this->pdo = $this->conn->DatabaseDefault();
				
			$this->sql = "INSERT INTO academics_matters (`cod_academic`, `cod_matter`, `date_insert`) VALUES (?, ?, ?)";
				
			$this->query = $this->pdo->prepare($this->sql);
			
			$error = [];
			/*Salva cada acadêmico com sua respectiva materia*/
			foreach ($data->academics as $index => $value){
				$this->query->bindValue(1, $value['id']);
				$this->query->bindValue(2, $data->matter);
				$this->query->bindValue(3, date("Y/m/d H:i:s"));
				
				if(!$this->query->execute()){
					$error[] = $this->queryError[2];
				}
			}
			
			if(count($error) != 0){
				parent::__destruct();
			
				return array("success" => 0, "alert" => $error);
			}else{
				parent::__destruct();
					
				return array("success" => 1);
			}
		}
		/*Selecionar todos os acadêmicos de todas as metérias*/
		public function selectAcademicsAndMatters(){
			/*Selecionando dados de conexao com o BD*/
			$this->conn = new DataBase();
			
			$this->pdo = $this->conn->DatabaseDefault();
		
			$this->sql = "SELECT am.id, a.rgm, a.name, m.title FROM academics_matters AS am, matters AS m, academic AS a
					WHERE am.cod_matter = m.id
					AND am.cod_academic = a.id;";
		
			$this->query = $this->pdo->prepare($this->sql);
		
			if($this->query->execute()){
				$rows = $this->query->fetchAll ( PDO::FETCH_OBJ );
					
				return array('success' => 1, 'data' => $rows);
			}else{
				$this->queryError = $this->query->errorInfo();
					
				parent::__destruct();
					
				return array("success" => 0, "alert" => "Error - ".$this->queryError[2]);
			}
		}
		/*Selecionar todos os acadêmicos*/
		public function selectAcademics($data){
			/*Selecionando dados de conexao com o BD*/
			$this->conn = new DataBase();
			
			$this->pdo = $this->conn->DatabaseDefault();
		
			$this->sql = "SELECT a.id, a.name, a.rgm, ac.email FROM academic AS a, academic_contact AS ac
					WHERE a.id = ac.cod_academic
					AND a.rgm LIKE ?";
		
			$this->query = $this->pdo->prepare($this->sql);
			
			$rgm = $data['rgm'];
			
			$this->query->bindValue(1, "%$rgm%", PDO::PARAM_STR);
		
			if($this->query->execute()){
				$rows = $this->query->fetchAll ( PDO::FETCH_OBJ );
					
				return array('success' => 1, 'data' => $rows);
			}else{
				$this->queryError = $this->query->errorInfo();
					
				parent::__destruct();
					
				return array("success" => 0, "alert" => "Error - ".$this->queryError[2]);
			}
		}
		
		/*Deletar um determinado acadêmico da matéria selecionada*/
		public function deleteAcademicMatter($idAcademic){
			/*Selecionando dados de conexao com o BD*/
			$this->conn = new DataBase();
		
			$this->pdo = $this->conn->DatabaseDefault();
		
			$this->sql = "DELETE FROM academics_matters WHERE id = ?";
		
			$this->query = $this->pdo->prepare($this->sql);
		
			$this->query->bindValue(1, $idAcademic);
		
			if($this->query->execute()){
				parent::__destruct();
					
				return array('success' => 1);
			}else{
				$this->queryError = $this->query->errorInfo();
					
				parent::__destruct();
					
				return array("success" => 0, "alert" => "Error - ".$this->queryError[2]);
			}
		}
		
		private function generatePassword($rgm){
			$hash = password_hash($rgm, PASSWORD_DEFAULT);
			
			$hash = str_replace(array("/","\/", ",", ".", "0", "o", "O"), "", $hash);
			
			return substr($hash, 10, 6);
		}
	}
?>